@@ -36,6 +36,90 @@ except ImportError:
     from urllib.parse import urlsplit
 
 
+__all__ = [
+    "__author__",
+    "__copyright__",
+    "__description__",
+    "__email__",
+    "__license__",
+    "__title__",
+    "__version__",
+    "assert_dir",
+    "assert_exists",
+    "assert_file",
+    "assert_not_dir",
+    "assert_not_exists",
+    "assert_not_file",
+    "clean_dir",
+    "convert_size_bytes_to_string",
+    "convert_size_string_to_bytes",
+    "copy_dir",
+    "copy_dir_content",
+    "copy_file",
+    "create_dir",
+    "create_file",
+    "create_zip_file",
+    "delete_dir",
+    "delete_dir_content",
+    "delete_dirs",
+    "delete_file",
+    "delete_files",
+    "download_file",
+    "exists",
+    "extract_zip_file",
+    "get_dir_creation_date",
+    "get_dir_creation_date_formatted",
+    "get_dir_last_modified_date",
+    "get_dir_last_modified_date_formatted",
+    "get_dir_size",
+    "get_dir_size_formatted",
+    "get_file_basename",
+    "get_file_creation_date",
+    "get_file_creation_date_formatted",
+    "get_file_extension",
+    "get_file_hash",
+    "get_file_last_modified_date",
+    "get_file_last_modified_date_formatted",
+    "get_file_size",
+    "get_file_size_formatted",
+    "get_filename",
+    "get_parent_dir",
+    "is_dir",
+    "is_empty",
+    "is_empty_dir",
+    "is_empty_file",
+    "is_file",
+    "join_filename",
+    "join_filepath",
+    "join_path",
+    "list_dirs",
+    "list_files",
+    "make_dirs",
+    "make_dirs_for_file",
+    "move_dir",
+    "move_file",
+    "read_file",
+    "read_file_from_url",
+    "read_file_json",
+    "read_file_lines",
+    "remove_dir",
+    "remove_dir_content",
+    "remove_dirs",
+    "remove_file",
+    "remove_files",
+    "rename_dir",
+    "rename_file",
+    "rename_file_basename",
+    "rename_file_extension",
+    "search_dirs",
+    "search_files",
+    "split_filename",
+    "split_filepath",
+    "split_path",
+    "write_file",
+    "write_file_json",
+]
+
 PY2 = bool(sys.version_info.major == 2)
 SIZE_UNITS = ["bytes", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"]
 
@@ -149,7 +233,7 @@ def convert_size_string_to_bytes(size):
     factor = units.index(unit.lower())
     if not factor:
         return amount
-    return int((1024 ** factor) * amount)
+    return int((1024**factor) * amount)
 
 
 def copy_dir(path, dest, overwrite=False, **kwargs):
@@ -241,9 +325,10 @@ def create_zip_file(
         elif is_dir(path):
             for item_name in os.listdir(path):
                 item_path = join_path(path, item_name)
-                if is_dir(item_path):
-                    basedir = join_path(basedir, item_name)
-                _write_content_to_zip_file(file, item_path, basedir)
+                item_basedir = (
+                    join_path(basedir, item_name) if is_dir(item_path) else basedir
+                )
+                _write_content_to_zip_file(file, item_path, item_basedir)
 
     with zipfile.ZipFile(path, "w", compression) as file:
         for content_path in content_paths:
